package com.aucma.dms.service;

//import com.aucma.dms.domain.DmsBaseDeviceInstall;

import com.aucma.dms.domain.DmsBaseDeviceInstall;

import java.util.List;

/**
 * 设备安装信息Service接口
 * 
 * @author xins
 * @date 2024-01-02
 */
public interface IDmsBaseDeviceInstallService 
{
    /**
     * 查询设备安装信息
     * 
     * @param deviceInstallId 设备安装信息主键
     * @return 设备安装信息
     */
    public DmsBaseDeviceInstall selectDmsBaseDeviceInstallByDeviceInstallId(Long deviceInstallId);

    /**
     * 查询设备安装信息列表
     * 
     * @param dmsBaseDeviceInstall 设备安装信息
     * @return 设备安装信息集合
     */
    public List<DmsBaseDeviceInstall> selectDmsBaseDeviceInstallList(DmsBaseDeviceInstall dmsBaseDeviceInstall);

    /**
     * 新增设备安装信息
     * 
     * @param dmsBaseDeviceInstall 设备安装信息
     * @return 结果
     */
    public int insertDmsBaseDeviceInstall(DmsBaseDeviceInstall dmsBaseDeviceInstall);

    /**
     * 修改设备安装信息
     * 
     * @param dmsBaseDeviceInstall 设备安装信息
     * @return 结果
     */
    public int updateDmsBaseDeviceInstall(DmsBaseDeviceInstall dmsBaseDeviceInstall);

    /**
     * 批量删除设备安装信息
     * 
     * @param deviceInstallIds 需要删除的设备安装信息主键集合
     * @return 结果
     */
    public int deleteDmsBaseDeviceInstallByDeviceInstallIds(Long[] deviceInstallIds);

    /**
     * 删除设备安装信息信息
     * 
     * @param deviceInstallId 设备安装信息主键
     * @return 结果
     */
    public int deleteDmsBaseDeviceInstallByDeviceInstallId(Long deviceInstallId);
}
